# libspwn

A CLI to easily create the file architecture and boilerplate for a SPWN library

## Installation

### MacOS and Linux Users

Install with pip

```bash
pip3 install libspwn
```

### Windows Users

I'm too lazy to implement multiplatform support

## Usage

Just run `libspwn init LIBRARYNAME` in an empty directory and it will create the necessary files
